@@ -6,6 +6,7 @@ use App::gh::Utils;
 use File::stat;
 use File::Temp;
 use Text::Wrap;
+use IO::Pager;
 require App::gh::Git;
 
 
@@ -63,6 +64,8 @@ sub run {
         die "Github authtoken not found. Can not get pull request.\n";
     }
 
+    local  $STDOUT = new IO::Pager *STDOUT;
+
     my $data = App::gh->api->pullreq_get($user, $repo, $number);
     my $pull = $data->{pull};
     printf "Title:    [%s] %s\n", ucfirst($pull->{state}) , $pull->{title};
